@@ -199,7 +199,7 @@ class PhpHelper
 	 * @param string|null $nameserver set additional resolver nameserver to use (e.g. 1.1.1.1)
 	 * @return bool|array
 	 */
-	public static function gethostbynamel6(string $host, bool $try_a = true, string $nameserver = null)
+	public static function gethostbynamel6(string $host, bool $try_a = true, ?string $nameserver = null)
 	{
 		$ips = [];
 
@@ -442,7 +442,7 @@ class PhpHelper
 	 * @param bool $asReturn
 	 * @return string
 	 */
-	public static function parseArrayToPhpFile(array $array, string $comment = null, bool $asReturn = false): string
+	public static function parseArrayToPhpFile(array $array, ?string $comment = null, bool $asReturn = false): string
 	{
 		$str = sprintf("<?php\n// %s\n\n", $comment ?? 'autogenerated froxlor file');
 
@@ -464,7 +464,7 @@ class PhpHelper
 	 * @param int $depth
 	 * @return string
 	 */
-	public static function parseArrayToString(array $array, string $key = null, int $depth = 1): string
+	public static function parseArrayToString(array $array, ?string $key = null, int $depth = 1): string
 	{
 		$str = '';
 		if (!is_null($key)) {
