@@ -25,6 +25,7 @@
 
 namespace Froxlor;
 
+use Exception;
 use Froxlor\Database\Database;
 use PDO;
 use PDOStatement;
@@ -129,12 +130,14 @@ class Settings
 	{
 		// set defaults
 		self::$conf = [
-			'enable_webupdate' => false
+			'enable_webupdate' => false,
+			'disable_otp_security_check' => false,
+			'display_php_errors' => false,
 		];
 
 		$configfile = Froxlor::getInstallDir() . '/lib/config.inc.php';
 		if (@file_exists($configfile) && is_readable($configfile)) {
-			self::$conf = include $configfile;
+			self::$conf = array_merge(self::$conf, include $configfile);
 		}
 		return true;
 	}
@@ -329,7 +332,7 @@ class Settings
 		}
 	}
 
-	public static function getAll() : array
+	public static function getAll(): array
 	{
 		self::init();
 		return self::$data;
@@ -337,17 +340,14 @@ class Settings
 
 	/**
 	 * get value from config by identifier
+	 * @throws Exception
 	 */
 	public static function Config(string $config)
 	{
 		self::init();
-		$sstr = explode(".", $config);
-		$result = self::$conf;
-		foreach ($sstr as $key) {
-			$result = $result[$key] ?? null;
-			if (empty($result)) {
-				break;
-			}
+		$result = self::$conf[$config] ?? null;
+		if (is_null($result)) {
+			throw new Exception('Unknown local config name "' . $config . '"');
 		}
 		return $result;
 	}
