@@ -97,7 +97,7 @@ return [
 						'checked' => (int)$result['iscatchall'],
 					],
 					'bypass_spam' => [
-						'visible' => Settings::Get('antispam.activated') == '1',
+						'visible' => Settings::Get('antispam.activated') == '1' && (int)Settings::Get('antispam.default_bypass_spam') <= 2,
 						'label' => lng('antispam.bypass_spam'),
 						'type' => 'checkbox',
 						'value' => '1',
@@ -112,7 +112,7 @@ return [
 						'value' => $result['spam_tag_level'],
 					],
 					'spam_rewrite_subject' => [
-						'visible' => Settings::Get('antispam.activated') == '1',
+						'visible' => Settings::Get('antispam.activated') == '1' && (int)Settings::Get('antispam.default_spam_rewrite_subject') <= 2,
 						'label' => lng('antispam.rewrite_subject'),
 						'type' => 'checkbox',
 						'value' => '1',
@@ -127,7 +127,7 @@ return [
 						'value' => $result['spam_kill_level']
 					],
 					'policy_greylist' => [
-						'visible' => Settings::Get('antispam.activated') == '1',
+						'visible' => Settings::Get('antispam.activated') == '1' && (int)Settings::Get('antispam.default_policy_greylist') <= 2,
 						'label' => lng('antispam.policy_greylist'),
 						'type' => 'checkbox',
 						'value' => '1',
