@@ -49,7 +49,7 @@ return [
 					'directory_password' => [
 						'label' => lng('login.password'),
 						'type' => 'password',
-						'autocomplete' => 'off',
+						'autocomplete' => 'new-password',
 						'next_to' => [
 							'directory_password_suggestion' => [
 								'next_to_prefix' => lng('customer.generated_pwd') . ':',
